@@ -34,7 +34,7 @@ xt::pyarray<double> example2(xt::pyarray<double>& m)
 double readme_example1(xt::pyarray<double>& m)
 {
     auto sines = xt::sin(m);
-    return std::accumulate(sines.begin(), sines.end(), 0.0);
+    return std::accumulate(sines.cbegin(), sines.cend(), 0.0);
 }
 
 double readme_example2(double i, double j)
